@@ -7,7 +7,7 @@ from copy import copy
 from io import BytesIO
 from time import time as get_current_timestamp
 
-from ..metadata.utils import DEFAULT_METADATA_VERSION, get_core_metadata_constructors
+from ..metadata.spec import DEFAULT_METADATA_VERSION, get_core_metadata_constructors
 from ..utils.constants import DEFAULT_BUILD_SCRIPT
 from .plugin.interface import BuilderInterface
 from .utils import get_reproducible_timestamp, normalize_archive_path, normalize_file_permissions, replace_file
@@ -16,7 +16,7 @@ from .utils import get_reproducible_timestamp, normalize_archive_path, normalize
 class SdistArchive(object):
     def __init__(self, name, reproducible):
         """
-        https://www.python.org/dev/peps/pep-0517/#source-distributions
+        https://peps.python.org/pep-0517/#source-distributions
         """
         self.name = name
         self.reproducible = reproducible
@@ -165,7 +165,7 @@ class SdistBuilder(BuilderInterface):
             contents += '    install_requires=[\n'
 
             for specifier in self.metadata.core.dependencies:
-                contents += '        {!r},\n'.format(specifier)
+                contents += '        {!r},\n'.format(specifier.replace("'", '"'))
 
             contents += '    ],\n'
 
@@ -179,7 +179,7 @@ class SdistBuilder(BuilderInterface):
                 contents += '        {!r}: [\n'.format(option)
 
                 for specifier in specifiers:
-                    contents += '            {!r},\n'.format(specifier)
+                    contents += '            {!r},\n'.format(specifier.replace("'", '"'))
 
                 contents += '        ],\n'
 
